<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/core/RUnit.cpp" line="+273"/>
        <source>None</source>
        <translation>Keine</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Inch</source>
        <translation>Inch</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Foot</source>
        <translation>Fuss</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Mile</source>
        <translation>Meile</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Millimeter</source>
        <translation>Millimeter</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Centimeter</source>
        <translation>Zentimeter</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Meter</source>
        <translation>Meter</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Kilometer</source>
        <translation>Kilometer</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Microinch</source>
        <translation>Mikroinch</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Mil</source>
        <translation>Mil</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Yard</source>
        <translation>Yard</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Angstrom</source>
        <translation>Angstrom</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Nanometer</source>
        <translation>Nanometer</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Micron</source>
        <translation>Mikron</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Decimeter</source>
        <translation>Dezimeter</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Decameter</source>
        <translation>Dekameter</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Hectometer</source>
        <translation>Hektometer</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Gigameter</source>
        <translation>Gigameter</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Astro</source>
        <translation>Astro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Lightyear</source>
        <translation>Lichtjahr</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Parsec</source>
        <translation>Parsec</translation>
    </message>
    <message>
        <source>Plu</source>
        <translation type="obsolete">Plu</translation>
    </message>
</context>
<context>
    <name>RColor</name>
    <message>
        <location filename="../src/core/RColor.cpp" line="+287"/>
        <source>By Layer</source>
        <translation>Von Layer</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>By Block</source>
        <translation>Von Block</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Red</source>
        <translation>Rot</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Yellow</source>
        <translation>Gelb</translation>
    </message>
    <message>
        <location line="-4"/>
        <source>Green</source>
        <translation>Grün</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Cyan</source>
        <translation>Cyan</translation>
    </message>
    <message>
        <location line="-1"/>
        <source>Blue</source>
        <translation>Blau</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Magenta</source>
        <translation>Magenta</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Orange</source>
        <translation>Orange</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Red</source>
        <translation>Dunkelrot</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Green</source>
        <translation>Dunkelgrün</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Blue</source>
        <translation>Dunkelblau</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Cyan</source>
        <translation>Dunkelcyan</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Magenta</source>
        <translation>Dunkelmagenta</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Yellow</source>
        <translation>Dunkelgelb</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Black</source>
        <translation>Schwarz</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>White</source>
        <translation>Weiss</translation>
    </message>
    <message>
        <location line="-2"/>
        <source>Gray</source>
        <translation>Grau</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Light Gray</source>
        <translation>Hellgrau</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Others...</source>
        <translation>Andere...</translation>
    </message>
</context>
<context>
    <name>RDocumentVariables</name>
    <message>
        <location filename="../src/core/RDocumentVariables.cpp" line="+45"/>
        <source>Current Layer ID</source>
        <translation>ID des aktuellen Layers</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Drawing Unit</source>
        <translation>Zeichnungseinheit</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Linetype Scale</source>
        <translation>Linientypskalierung</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dimension Font</source>
        <translation>Bemassungsschriftart</translation>
    </message>
</context>
<context>
    <name>REntity</name>
    <message>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="+92"/>
        <source>Block</source>
        <translation>Block</translation>
    </message>
    <message>
        <source>Referenced Block</source>
        <translation type="obsolete">Referenzierter Block</translation>
    </message>
    <message>
        <location filename="../src/core/RBlock.cpp" line="+66"/>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="+1"/>
        <location line="+3"/>
        <location filename="../src/core/RLayout.cpp" line="+82"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/core/RTextBasedEntity.cpp" line="+72"/>
        <location filename="../src/core/RViewportEntity.cpp" line="+73"/>
        <location line="+8"/>
        <location line="+2"/>
        <source>X</source>
        <translation>X</translation>
    </message>
    <message>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-3"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-10"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Position</source>
        <translation>Position</translation>
    </message>
    <message>
        <location filename="../src/core/RBlock.cpp" line="-1"/>
        <source>Pixel Unit</source>
        <translation>Pixeleinheit</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Origin</source>
        <translation>Ursprung</translation>
    </message>
    <message>
        <location line="-1"/>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-1"/>
        <location line="+3"/>
        <location filename="../src/core/RLayout.cpp" line="-11"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/core/RTextBasedEntity.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-1"/>
        <location line="+8"/>
        <location line="+2"/>
        <source>Y</source>
        <translation>Y</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/core/RLayout.cpp" line="-11"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/core/RTextBasedEntity.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-9"/>
        <location line="+10"/>
        <source>Z</source>
        <translation>Z</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Layout</source>
        <translation>Layout</translation>
    </message>
    <message>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-7"/>
        <source>Scale</source>
        <translation>Skalierung</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Angle</source>
        <translation>Winkel</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Columns</source>
        <translation>Spalten</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Rows</source>
        <translation>Reihen</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Column Spacing</source>
        <translation>Spaltenabstand</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Row Spacing</source>
        <translation>Reihenabstand</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Attributes</source>
        <translation>Attribute</translation>
    </message>
    <message>
        <location filename="../src/core/REntity.cpp" line="+87"/>
        <location filename="../src/core/RObject.cpp" line="+66"/>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Block ID</source>
        <translation>Block ID</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Layer</source>
        <translation>Layer</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayer.cpp" line="+99"/>
        <source>Linetype</source>
        <translation>Linientyp</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Linetype Scale</source>
        <translation>Linientypskalierung</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayer.cpp" line="+1"/>
        <source>Lineweight</source>
        <translation>Linienstärke</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayer.cpp" line="-2"/>
        <source>Color</source>
        <translation>Farbe</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Displayed Color</source>
        <translation>Angezeigte Farbe</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Draw Order</source>
        <translation>Reihenfolge</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Boundary</source>
        <translation>Begrenzung</translation>
    </message>
    <message>
        <location line="-3"/>
        <location filename="../src/core/RLayout.cpp" line="+3"/>
        <source>Left</source>
        <translation>Links</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Bottom</source>
        <translation>Unten</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Right</source>
        <translation>Rechts</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Top</source>
        <translation>Oben</translation>
    </message>
    <message>
        <location filename="../src/core/RObject.cpp" line="-1"/>
        <location filename="../src/core/RPropertyTypeId.cpp" line="+108"/>
        <source>Custom</source>
        <translation>Benutzerdefiniert</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Handle</source>
        <translation>Handle</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Protected</source>
        <translation>Geschützt</translation>
    </message>
    <message>
        <location filename="../src/core/REntity.cpp" line="+2"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-2"/>
        <source>Width</source>
        <translation>Breite</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+1"/>
        <source>Size</source>
        <translation>Grösse</translation>
    </message>
    <message>
        <location line="+0"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="+1"/>
        <source>Height</source>
        <translation>Höhe</translation>
    </message>
    <message>
        <location filename="../src/core/RTextBasedEntity.cpp" line="-3"/>
        <source>Simple</source>
        <translation>Einfach</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Text Position</source>
        <translation>Text Position</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plain Text</source>
        <translation>Klartext</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Font Name</source>
        <translation>Schriftart</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text Height</source>
        <translation>Texthöhe</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text Angle</source>
        <translation>Textwinkel</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>X Scale</source>
        <translation>X Skalierung</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Bold</source>
        <translation>Fett</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Italic</source>
        <translation>Kursiv</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Line Spacing</source>
        <translation>Linienabstand</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <source>Alignment</source>
        <translation>Ausrichtung</translation>
    </message>
    <message>
        <location line="-1"/>
        <source>Horizontal</source>
        <translation>Horizontal</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Vertical</source>
        <translation>Vertikal</translation>
    </message>
    <message>
        <location filename="../src/core/RViewportEntity.cpp" line="+2"/>
        <source>Rotation</source>
        <translation>Rotation</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>On</source>
        <translation>Ein</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <source>View Center</source>
        <translation>Ansicht Zentrum</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>View Target</source>
        <translation>Ansicht Ziel</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Overall</source>
        <translation>Umfassend</translation>
    </message>
    <message>
        <location filename="../src/core/RBlock.cpp" line="-6"/>
        <location filename="../src/core/RLayer.cpp" line="-8"/>
        <location filename="../src/core/RLayout.cpp" line="-24"/>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Hidden</source>
        <translation>Verdeckt</translation>
    </message>
    <message>
        <location filename="../src/core/RLayer.cpp" line="+1"/>
        <source>Off</source>
        <translation>Inaktiv</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Frozen</source>
        <translation>Gefroren</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Locked</source>
        <translation>Gesperrt</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Collapsed</source>
        <translation>Eingeklappt</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plottable</source>
        <translation>Plotbar</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Snappable</source>
        <translation>Fangbar</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Off is Freeze</source>
        <translation>Aus ist einfrieren</translation>
    </message>
    <message>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Tab Order</source>
        <translation>Tab Reihenfolge</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Min Limits</source>
        <translation>Min Begrenzung</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Max Limits</source>
        <translation>Max Begrenzung</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Insertion Base</source>
        <translation>Einfügungsbasis</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Min Extents</source>
        <translation>Min Ausmass</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Max Extents</source>
        <translation>Max Ausmass</translation>
    </message>
    <message>
        <source>Plot Margins</source>
        <translation type="obsolete">Plot Ränder</translation>
    </message>
    <message>
        <source>Plot Paper Size</source>
        <translation type="obsolete">Plot Papiergrösse</translation>
    </message>
    <message>
        <location filename="../src/core/RBlockReferenceData.cpp" line="+627"/>
        <source>Circular (recursive) block referencing detected:</source>
        <translation>Circuläre (rekursive) Blockreferenzierung detektiert:</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Block name:</source>
        <translation>Blockname:</translation>
    </message>
</context>
<context>
    <name>RGuiAction</name>
    <message>
        <location filename="../src/core/RGuiAction.cpp" line="+184"/>
        <source>Requires selection</source>
        <translation>Benötigt Selektion</translation>
    </message>
</context>
<context>
    <name>RImporter</name>
    <message numerus="yes">
        <source>Grounded %n recursive block reference(s) in blocks: %1</source>
        <translation type="obsolete">
            <numerusform>Eine Blockreferenz geerdet in Blöcken: %1</numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>RLayer</name>
    <message>
        <source>Name</source>
        <translation type="vanished">Name</translation>
    </message>
    <message>
        <source>Frozen</source>
        <translation type="vanished">Versteckt</translation>
    </message>
    <message>
        <source>Hidden</source>
        <translation type="vanished">Verdeckt</translation>
    </message>
    <message>
        <source>Locked</source>
        <translation type="vanished">Gesperrt</translation>
    </message>
    <message>
        <source>Color</source>
        <translation type="vanished">Farbe</translation>
    </message>
    <message>
        <source>Linetype</source>
        <translation type="vanished">Linientyp</translation>
    </message>
    <message>
        <source>Lineweight</source>
        <translation type="vanished">Linienstärke</translation>
    </message>
</context>
<context>
    <name>RLinetype</name>
    <message>
        <source>By Layer</source>
        <translation type="vanished">Von Layer</translation>
    </message>
    <message>
        <source>By Block</source>
        <translation type="vanished">Von Block</translation>
    </message>
    <message>
        <source>Continuous</source>
        <translation type="vanished">Durchgehend</translation>
    </message>
    <message>
        <source>Dot</source>
        <translation type="vanished">Gepunktet</translation>
    </message>
    <message>
        <source>Dot (small)</source>
        <translation type="vanished">Gepunktet (klein)</translation>
    </message>
    <message>
        <source>Dot (large)</source>
        <translation type="vanished">Gepunktet (gross)</translation>
    </message>
    <message>
        <source>Dash</source>
        <translation type="vanished">Gestrichelt</translation>
    </message>
    <message>
        <source>Dash (small)</source>
        <translation type="vanished">Gestrichelt (klein)</translation>
    </message>
    <message>
        <source>Dash (large)</source>
        <translation type="vanished">Gestrichelt (gross)</translation>
    </message>
    <message>
        <source>Dash Dot</source>
        <translation type="vanished">Strich Punkt</translation>
    </message>
    <message>
        <source>Dash Dot (small)</source>
        <translation type="vanished">Strich Punkt (klein)</translation>
    </message>
    <message>
        <source>Dash Dot (large)</source>
        <translation type="vanished">Strich Punkt (gross)</translation>
    </message>
    <message>
        <source>Divide</source>
        <translation type="vanished">Trennen</translation>
    </message>
    <message>
        <source>Divide (small)</source>
        <translation type="vanished">Trennung (klein)</translation>
    </message>
    <message>
        <source>Divide (large)</source>
        <translation type="vanished">Trennung (gross)</translation>
    </message>
    <message>
        <source>Center</source>
        <translation type="vanished">Zentrum</translation>
    </message>
    <message>
        <source>Center (small)</source>
        <translation type="vanished">Mittellinie (klein)</translation>
    </message>
    <message>
        <source>Center (large)</source>
        <translation type="vanished">Mittellinie (gross)</translation>
    </message>
    <message>
        <source>Border</source>
        <translation type="vanished">Rahmen</translation>
    </message>
    <message>
        <source>Border (small)</source>
        <translation type="vanished">Rahmen (klein)</translation>
    </message>
    <message>
        <source>Border (large)</source>
        <translation type="vanished">Rahmen (gross)</translation>
    </message>
    <message>
        <location filename="../src/core/RLinetype.cpp" line="+48"/>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Description</source>
        <translation>Beschreibung</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Metric</source>
        <translation>Metrisch</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Pattern</source>
        <translation>Muster</translation>
    </message>
</context>
<context>
    <name>RLinetypePattern</name>
    <message>
        <location filename="../src/core/RLinetypePattern.cpp" line="+856"/>
        <source>By Layer</source>
        <translation>Von Layer</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>By Block</source>
        <translation>Von Block</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Continuous</source>
        <translation>Durchgehend</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Border</source>
        <translation>Rand</translation>
    </message>
    <message>
        <source>Border (2x)</source>
        <translation type="vanished">Rand (2x)</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Center</source>
        <translation>Mitte</translation>
    </message>
    <message>
        <source>Center (2x)</source>
        <translation type="vanished">Mitte (2x)</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dash dot</source>
        <translation>Strichpunkt</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dashed</source>
        <translation>Strichlinie</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Divide</source>
        <translation>Getrennt</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dot</source>
        <translation>Punkt</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Hidden</source>
        <translation>Verdeckt</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Phantom</source>
        <translation>Phantom</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>ISO dash</source>
        <translation>ISO Strichlinie</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash space</source>
        <translation>ISO Gestrichelt mit Abstand</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash dot</source>
        <translation>ISO Lang gestrichelt punktiert</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash double-dot</source>
        <translation>ISO Lang gestrichelt doppelpunktiert</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash triple-dot</source>
        <translation>ISO Lang gestrichelt dreifachpunktiert</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dot</source>
        <translation>ISO Punktiert</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash short-dash</source>
        <translation>ISO Lang kurz gestrichelt</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash double-short-dash</source>
        <translation>ISO Lang kurz-kurz gestrichelt</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash dot</source>
        <translation>ISO Strichpunktlinie</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO double-dash dot</source>
        <translation>ISO Zwei Striche, Punkt</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash double-dot</source>
        <translation>ISO Strich, zwei Punkte</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO double-dash double-dot</source>
        <translation>ISO zwei Striche, zwei Punkte</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash triple-dot</source>
        <translation>ISO Strich, drei Punkte</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO double-dash triple-dot</source>
        <translation>ISO Zwei Striche, drei Punkte</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Hot Water Supply</source>
        <translation>Heisswasserleitung</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Hot Water</source>
        <translation>Heisswasser</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Gas Line</source>
        <translation>Gasleitung</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Batting</source>
        <translation>Isolation</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Zig Zag</source>
        <translation>Zickzack</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Tracks</source>
        <translation>Eisenbahn</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Fenceline 1</source>
        <translation>Grenze rund</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Fenceline 2</source>
        <translation>Grenze eckig</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Drainage</source>
        <translation>Entwässerung</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Drainage Reversed</source>
        <translation>Entwässerung umgekehrt</translation>
    </message>
    <message>
        <source>Drainage Reverse</source>
        <translation type="vanished">Entwässerung umgekehrt</translation>
    </message>
</context>
<context>
    <name>RLineweight</name>
    <message>
        <location filename="../src/core/RLineweight.cpp" line="+35"/>
        <source>By Layer</source>
        <translation>Von Layer</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>By Block</source>
        <translation>Von Block</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.00mm</source>
        <translation>0.00mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.05mm</source>
        <translation>0.05mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.09mm</source>
        <translation>0.09mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.13mm (ISO)</source>
        <translation>0.13mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.15mm</source>
        <translation>0.15mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.18mm (ISO)</source>
        <translation>0.18mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.20mm</source>
        <translation>0.20mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.25mm (ISO)</source>
        <translation>0.25mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.30mm</source>
        <translation>0.30mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.35mm (ISO)</source>
        <translation>0.35mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.40mm</source>
        <translation>0.40mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.50mm (ISO)</source>
        <translation>0.50mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.53mm</source>
        <translation>0.53mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.60mm</source>
        <translation>0.60mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.70mm (ISO)</source>
        <translation>0.70mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.80mm</source>
        <translation>0.80mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.90mm</source>
        <translation>0.90mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.00mm (ISO)</source>
        <translation>1.00mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.06mm</source>
        <translation>1.06mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.20mm</source>
        <translation>1.20mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.40mm (ISO)</source>
        <translation>1.40mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.58mm</source>
        <translation>1.58mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>2.00mm (ISO)</source>
        <translation>2.00mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>2.11mm</source>
        <translation>2.11mm</translation>
    </message>
</context>
<context>
    <name>RObject</name>
    <message>
        <source>Custom</source>
        <translation type="vanished">Benutzerdefiniert</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="vanished">Typ</translation>
    </message>
    <message>
        <source>Handle</source>
        <translation type="vanished">Handle</translation>
    </message>
    <message>
        <source>Protected</source>
        <translation type="vanished">Geschützt</translation>
    </message>
</context>
</TS>
